Skip to main content

Kick-dl

🚀 Kick-dl is a Python package and CLI tool for fetching and downloading VoDs from Kick channels. It supports selecting specific VoDs, listing available streams, downloading all VoDs, and customizing download quality and concurrency.

Supported Python versions PEP8


📋 Features

  • 🎥 Fetch VoDs from a specified Kick channel.
  • 📑 List available VoDs with titles and dates.
  • 📥 Download specific VoDs by index or download all available VoDs.
  • 🎛 Customize download quality (e.g., 720p60, 1080p60).
  • ⚡ Supports concurrent downloads for efficiency.
  • 🔗 Option to output download URLs without downloading the VoDs.

Requirements


⬇️ Installation

Install Kick-dl using pip:

pip install kick-dl

⌨️ Usage

To view all available options, use:

kick-dl --help

Example Help Output:

usage: kick-dl [-h] -c CHANNEL_NAME [-i VOD_INDEX] [-l] [-a] [-nd] [-q QUALITY] [-C N_CONCURRENT_DOWNLOADS]

Download Kick VoDs from a specified channel.

options:
  -h, --help            show this help message and exit
  -c CHANNEL_NAME, --channel_name CHANNEL_NAME
                        The name of the channel to fetch VoDs from.
  -i VOD_INDEX, --vod_index VOD_INDEX
                        The index or list of indexes of the VoD(s) to download. Use 0 for the most recent VoD, 1 for the second
                        most recent, and so on. Provide a single index or a comma-separated list of integers.
  -l, --list_indexes    List all available VoDs with their titles and dates for easy selection.
  -a, --download_all    Download all available VoDs without selecting specific indexes.
  -nd, --no_download    Do not download the VoD. Instead, output the VoD download URL(s).
  -q QUALITY, --quality QUALITY
                        Specify the desired quality of the VoD. Defaults to the highest quality available. Common options include
                        160p, 360p, 480p, 720p60, and 1080p60.
  -C N_CONCURRENT_DOWNLOADS, --n_concurrent_downloads N_CONCURRENT_DOWNLOADS
                        Set the number of concurrent downloads. Defaults to 1.

📕 Examples

1. Download the Latest VoD

kick-dl -c <channel_name> -i 0

2. Download Multiple Specific VoDs by Index

kick-dl -c <channel_name> -i 0,1,2

3. List All Available VoDs

kick-dl -c <channel_name> -l

4. Download All Available VoDs

kick-dl -c <channel_name> -a

5. Specify the Quality and Concurrent Downloads

kick-dl -c <channel_name> -i 0 -q 720p60 -C 3

6. Output the Download URL Without Downloading

kick-dl -c <channel_name> -i 0 -nd

📝 License

This project is licensed under the MIT License.


Metadata

Release files for kick-dl 0.1.0

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for kick-dl 0.1.0
File Size Uploaded
kick_dl-0.1.0.tar.gz 3.4 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for kick-dl 0.1.0
File Interpreter ABI Platform
kick_dl-0.1.0-py3-none-any.whl Python 3 none any Details

Total release size: 7.8 kB

Release files / kick_dl-0.1.0.tar.gz

Download URL kick_dl-0.1.0.tar.gz
Size 3.4 kB
Tags Source
SHA-256 checksum
How to use checksums
6e99e9b3fbb954b75c2fc6275d1320e2e1994f1419cb28a024c3b959d99a185c
BLAKE2b-256 checksum
How to use checksums
5a06f8ff726fabbb2b087097f94c35aeafd1b2a08f96349506b488e598a67629
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via poetry/1.8.3 CPython/3.10.8 Darwin/24.1.0

Release files / kick_dl-0.1.0-py3-none-any.whl

Download URL kick_dl-0.1.0-py3-none-any.whl
Size 4.3 kB
Tags Python 3
SHA-256 checksum
How to use checksums
3f0c54c7a2b766128b91db4304be5749199c5dee715d19ce9aa79d4d3b651649
BLAKE2b-256 checksum
How to use checksums
7a69a7498c8fee28e0c772ff73d419b5df6d53437d5d962d963b82e02a8dc547
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via poetry/1.8.3 CPython/3.10.8 Darwin/24.1.0

Release history Release notifications | RSS feed

This release

0.1.0 This release

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page